@@ -24,7 +24,7 @@
 ## @example
 ## @group
 ## cos (infsup (1))
-##   @result{} [0.5403023058681396, 0.5403023058681398]
+##   @result{} ans ⊂ [0.5403023058681396, 0.5403023058681398]
 ## @end group
 ## @end example
 ## @seealso{@@infsup/acos, @@infsup/sec, @@infsup/cosh}
