@@ -24,7 +24,7 @@
 ## @example
 ## @group
 ## expm1 (infsup (eps))
-##   @result{} [2.220446049250313e-16, 2.2204460492503136e-16]
+##   @result{} ans ⊂ [2.220446049250313e-16, 2.2204460492503136e-16]
 ## @end group
 ## @end example
 ## @seealso{@@infsup/exp, @@infsup/log1p}
