@@ -60,29 +60,29 @@
 ## @example
 ## @group
 ## infsup ()
-##   @result{} [Empty]
+##   @result{} ans = [Empty]
 ## infsup ("[1]")
-##   @result{} [1]
+##   @result{} ans = [1]
 ## infsup (2, 3)
-##   @result{} [2, 3]
+##   @result{} ans = [2, 3]
 ## infsup ("0.1")
-##   @result{} [0.09999999999999999, 0.1000000000000001]
+##   @result{} ans ⊂ [0.09999999999999999, 0.1000000000000001]
 ## infsup ("0.1", "0.2")
-##   @result{} [0.09999999999999999, 0.2000000000000001]
+##   @result{} ans ⊂ [0.09999999999999999, 0.2000000000000001]
 ## infsup ("0xff", "0x1.ffp14")
-##   @result{} [255, 32704]
+##   @result{} ans = [255, 32704]
 ## infsup ("1/3")
-##   @result{} [0.3333333333333333, 0.33333333333333338]
+##   @result{} ans ⊂ [0.3333333333333333, 0.33333333333333338]
 ## infsup ("[1/9, 47/11]")
-##   @result{} [0.1111111111111111, 4.272727272727274]
+##   @result{} ans ⊂ [0.1111111111111111, 4.272727272727274]
 ## infsup ("7.3?9u")
-##   @result{} [7.299999999999999, 8.200000000000002]
+##   @result{} ans ⊂ [7.299999999999999, 8.200000000000002]
 ## infsup ("0??")
-##   @result{} [Entire]
+##   @result{} ans = [Entire]
 ## infsup ("911??de-2")
-##   @result{} [-Inf, +9.110000000000002]
+##   @result{} ans ⊂ [-Inf, +9.110000000000002]
 ## infsup ("10?")
-##   @result{} [9.5, 10.5]
+##   @result{} ans = [9.5, 10.5]
 ## @end group
 ## @end example
 ## @seealso{exacttointerval}
