@@ -41,7 +41,7 @@
 ## @example
 ## @group
 ## dilog (infsupdec (1))
-##   @result{} [1.6449340668482264, 1.6449340668482267]_com
+##   @result{} ans ⊂ [1.6449340668482264, 1.6449340668482267]_com
 ## @end group
 ## @end example
 ## @end deftypefn
