@@ -30,7 +30,7 @@
 ## x = infsupdec (1, 3);
 ## y = infsupdec (2, 4);
 ## intersect (x, y)
-##   @result{} [2, 3]_trv
+##   @result{} ans = [2, 3]_trv
 ## @end group
 ## @end example
 ## @seealso{@@infsupdec/union, @@infsupdec/setdiff, @@infsupdec/setxor}
